#!/usr/bin/php
<?php

function do_call($curl, $command, array $postdata) {
	$base_url = 'http://localhost/api';
	curl_setopt_array(
		$curl,
		[
			CURLOPT_URL => "{$base_url}/{$command}",
			CURLOPT_POST => true,
			CURLOPT_FOLLOWLOCATION => true,
			CURLOPT_SSL_VERIFYPEER => false,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_POSTFIELDS => $postdata,
		]
	);
	return @json_decode(@curl_exec($curl));
}

function fetch_token($curl) {
	$maintenance_key = trim(@file_get_contents('/etc/ombutel/ombutel-maint.conf'));
	$response = do_call($curl, 'authenticate', [ 'key' => $maintenance_key ]);
	if (!$response || $response->status != 'success') {
		throw new \Exception('Authentication failed');
	}
	return $response->data->token;
}

function create_module($curl, $token, $name, $admin, $portal) {
	$response = do_call($curl, 'modules', [ 'token' => $token ]);
	if (!$response || $response->status != 'success') {
		throw new \Exception("Creation of module \"{$name}\" failed");
	}
	foreach ($response->data as $module) {
		if ($module->name == $name) {
			return $module->module_id;
		}
	}
	$response = do_call(
		$curl,
		'create_module',
		[
			'token' => $token,
			'name' => $name,
			'has_dialplan' => 'no',
			'admin' => ($admin) ? 'yes' : 'no',
			'portal' => ($portal) ? 'yes' : 'no',
			'version' => '1.0',
		]
	);
	if (!$response || $response->status != 'success') {
		throw new \Exception("Creation of module \"{$name}\" failed");
	}
	return $response->data->module_id;
}

function create_menu($curl, $token, $label, $parent_id, $module_id, $icon = null) {
	$response = do_call($curl, 'menus', [ 'token' => $token ]);
	if (!$response || $response->status != 'success') {
		throw new \Exception("Creation of menu \"{$label}\" failed");
	}
	$last_sort = 0;
	foreach ($response->data as $menu) {
		if ($menu->label == $label) {
			return $menu->menu_id;
		}
		if ($menu->parent_id == $parent_id) {
			$last_sort = max($menu->sort, $last_sort);
		}
	}
	$response = do_call(
		$curl,
		'create_menu',
		[
			'token' => $token,
			'label' => $label,
			'parent_id' => $parent_id,
			'module_id' => $module_id,
			'icon' => $icon,
			'sort' => ($last_sort + 1),
		]
	);
	if (!$response || $response->status != 'success') {
		throw new \Exception("Creation of menu \"{$label}\" failed");
	}
	return $response->data->menu_id;
}

echo "Init CURL".PHP_EOL;
$curl = curl_init();
echo "Fetching token ... ";
$token = fetch_token($curl);
echo $token.PHP_EOL;

// Create Supervision Manager module
echo "Fetching admin module ID ... ";
$sv_admin_module_id = create_module($curl, $token, 'supervision_admin', true, false);
echo $sv_admin_module_id.PHP_EOL;

// Desired menu tree
// SETTINGS -> APP MANAGERS -> Supervision Manager

// Create Supervision Manager menu
echo "Fetching menu root ID ... ";
$menu_root_id = create_menu($curl, $token, 'menu.settings', null, null); // level-1
echo $menu_root_id.PHP_EOL;


echo "Fetching admin menu ID ... ";
$sv_admin_menu_id = create_menu($curl, $token, 'menu.app_manager', $menu_root_id, null, 'fa fa-desktop fa-fw'); // level-2
echo $sv_admin_menu_id.PHP_EOL;
create_menu($curl, $token, 'menu.supervision_admin', $sv_admin_menu_id, $sv_admin_module_id); // level-3

// Create Supervision portal module
echo "Fetching module ID ... ";
$sv_module_id = create_module($curl, $token, 'supervision', false, true);
echo $sv_module_id.PHP_EOL;

//Desired menu tree
//OPERATOR -> SWITCHBOARD -> Supervision

// Create Supervision Switchboard menu in portal
echo "Fetching root ID ... ";
$root_id = create_menu($curl, $token, 'menu.operator', null, null, 'fa fa-desktop fa-fw'); // level-1
echo $root_id.PHP_EOL;
echo "Fetching supervision menu ID ... ";
$supervision_menu_id = create_menu($curl, $token, 'menu.switchboard', $root_id, null, 'fa fa-desktop fa-fw'); // level-2
echo $root_id.PHP_EOL;
create_menu($curl, $token, 'menu.supervision', $supervision_menu_id, $sv_module_id); // level-3

curl_close($curl);
echo "Finished.".PHP_EOL;
exit(0);

?>
